@@ -193,7 +193,8 @@ Usage:
         help="average number of CPUs",
         default=get_env_value_or_none("quota-cpu", float),
     )
-    DEFAULT_TMPDIR = "/tmp/duckietown/DT18/evaluator/executions"
+    user = getpass.getuser()
+    DEFAULT_TMPDIR = f"/tmp/{user}/duckietown/DT18/evaluator/executions"
 
     parser.add_argument(
         "--tmpdir", help="Location of temp dir", default=get_env_value_or_none("tmpdir", str, DEFAULT_TMPDIR)
