@@ -27,11 +27,11 @@ from duckietown_build_utils import (
     DockerRegistryName,
     get_duckietown_labels,
     get_important_env_build_args_dict,
+    log_in_for_build,
     pull_for_build,
     run_build,
     update_versions,
 )
-from duckietown_build_utils.docker_building import log_in_for_build
 from duckietown_challenges import (
     CHALLENGE_PREVIOUS_STEPS_DIR,
     ChallengeResults,
